import {Component, Input, OnDestroy, OnInit} from '@angular/core';
import {LecturerDataService} from 'src/app/services/lecturer-data.service';
import {QuestionAnswerPairDao} from 'src/app/dao/question-answer-pair.dao';
import {Observable} from 'rxjs';
import {AnswerSetDao} from 'src/app/dao/answer-set.dao';

@Component({
  selector: 'app-lecturer-response-view',
  templateUrl: './lecturer-response-view.component.html',
  styleUrls: ['./lecturer-response-view.component.css']
})
export class LecturerResponseViewComponent implements OnInit, OnDestroy {

  private eventSubscription: any;
  @Input() viewEvent: Observable<any>;
  public questionAnswerPairs: QuestionAnswerPairDao[];
  public username;
  public ready: boolean;

  constructor(private lecturerDataService: LecturerDataService) {
  }

  ngOnInit(): void {
    this.ready = false;
    this.eventSubscription = this.viewEvent.subscribe((data) => {
      this.questionAnswerPairs = [];
      this.username = data.answerSets[0].username;
      this.generatePairs(data);
      this.ready = true;
    });
  }

  ngOnDestroy(): void {
    this.questionAnswerPairs = [];
    this.eventSubscription.unsubscribe();
  }

  private generatePairs(data: AnswerSetDao) {
    for (let i = 0; i < this.lecturerDataService.currentQuestions.length; i++) {
      if (this.lecturerDataService.currentQuestions[i] && data.answerSets[i]) {
        this.questionAnswerPairs.push(new QuestionAnswerPairDao(this.lecturerDataService.currentQuestions[i], data.answerSets[i]));
      }
    }
  }


}
